# Gaurav Surve 12SDD2 Project - Typing Test
 
This is my Year 12 SDD Project.
I created a Touch Typing Program, aimed at helping kids learn type faster.


INSTRUCTIONS:
- Press Begin to go to main window.
- Press box at the bottom of the window to start typing.
- Select from 10, 30, and 60 seconds to decide what time you want to choose.

KEYBINDS:
- Open Program: SHIFT + ENTER 
- Close Program: SHIFT + ESCAPE
- Go Back: ESCAPE
- Restart: ENTER

BIBLIOGRAPHY/ SOURCES THAT HELPED
- Codemy.com --> Provided assistance in using Customtkinter and especially with scaling.
    https://www.youtube.com/c/Codemycom
- W3 Schools (JSON FILES, but also other things)
    https://www.w3schools.com/python/python_json.asp
- Stack Overflow --> Helped to get general assistance for any bugs or issues I encountered. 
    https://stackoverflow.com/
- Github --> Repository
    https://github.com/
- CHATGPT was used to source words for my words.json list. This was the fastest way to source words for this project, and the only time any AI was used in the making of this task. 




Thanks, 
- Gaurav